@@ -7,7 +7,7 @@ class NOTE:
     def __init__(self):
         print('initialize')
 
-    def Email(self, API_ID, API_PASSWORD):
+    def Mail(self, API_ID, API_PASSWORD):
         print("EMAIL Selected")
         return Mail(API_ID, API_PASSWORD)
 
